@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-# Copyright 2020 Google LLC
+# Copyright 2022 Google LLC
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -13,21 +13,20 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 #
-import warnings
 from typing import Callable, Dict, Optional, Sequence, Tuple, Union
+import warnings
 
-from google.api_core import grpc_helpers
-from google.api_core import gapic_v1
+from google.api_core import gapic_v1, grpc_helpers
 import google.auth  # type: ignore
 from google.auth import credentials as ga_credentials  # type: ignore
 from google.auth.transport.grpc import SslCredentials  # type: ignore
-
+from google.protobuf import empty_pb2  # type: ignore
 import grpc  # type: ignore
 
-from google.cloud.bigquery_reservation_v1.types import reservation
 from google.cloud.bigquery_reservation_v1.types import reservation as gcbr_reservation
-from google.protobuf import empty_pb2  # type: ignore
-from .base import ReservationServiceTransport, DEFAULT_CLIENT_INFO
+from google.cloud.bigquery_reservation_v1.types import reservation
+
+from .base import DEFAULT_CLIENT_INFO, ReservationServiceTransport
 
 
 class ReservationServiceGrpcTransport(ReservationServiceTransport):
@@ -176,8 +175,11 @@ class ReservationServiceGrpcTransport(ReservationServiceTransport):
         if not self._grpc_channel:
             self._grpc_channel = type(self).create_channel(
                 self._host,
+                # use the credentials which are saved
                 credentials=self._credentials,
-                credentials_file=credentials_file,
+                # Set ``credentials_file`` to ``None`` here as
+                # the credentials that we saved earlier should be used.
+                credentials_file=None,
                 scopes=self._scopes,
                 ssl_credentials=self._ssl_channel_credentials,
                 quota_project_id=quota_project_id,
@@ -239,8 +241,7 @@ class ReservationServiceGrpcTransport(ReservationServiceTransport):
 
     @property
     def grpc_channel(self) -> grpc.Channel:
-        """Return the channel designed to connect to this service.
-        """
+        """Return the channel designed to connect to this service."""
         return self._grpc_channel
 
     @property
@@ -547,8 +548,8 @@ class ReservationServiceGrpcTransport(ReservationServiceTransport):
 
         For example, in order to downgrade from 10000 slots to 8000, you
         might split a 10000 capacity commitment into commitments of 2000
-        and 8000. Then, you would change the plan of the first one to
-        ``FLEX`` and then delete it.
+        and 8000. Then, you delete the first one after the commitment
+        end time passes.
 
         Returns:
             Callable[[~.SplitCapacityCommitmentRequest],
@@ -891,6 +892,34 @@ class ReservationServiceGrpcTransport(ReservationServiceTransport):
             )
         return self._stubs["move_assignment"]
 
+    @property
+    def update_assignment(
+        self,
+    ) -> Callable[[reservation.UpdateAssignmentRequest], reservation.Assignment]:
+        r"""Return a callable for the update assignment method over gRPC.
+
+        Updates an existing assignment.
+
+        Only the ``priority`` field can be updated.
+
+        Returns:
+            Callable[[~.UpdateAssignmentRequest],
+                    ~.Assignment]:
+                A function that, when called, will call the underlying RPC
+                on the server.
+        """
+        # Generate a "stub function" on-the-fly which will actually make
+        # the request.
+        # gRPC handles serialization and deserialization, so we just need
+        # to pass in the functions for each.
+        if "update_assignment" not in self._stubs:
+            self._stubs["update_assignment"] = self.grpc_channel.unary_unary(
+                "/google.cloud.bigquery.reservation.v1.ReservationService/UpdateAssignment",
+                request_serializer=reservation.UpdateAssignmentRequest.serialize,
+                response_deserializer=reservation.Assignment.deserialize,
+            )
+        return self._stubs["update_assignment"]
+
     @property
     def get_bi_reservation(
         self,
@@ -953,5 +982,9 @@ class ReservationServiceGrpcTransport(ReservationServiceTransport):
     def close(self):
         self.grpc_channel.close()
 
+    @property
+    def kind(self) -> str:
+        return "grpc"
+
 
 __all__ = ("ReservationServiceGrpcTransport",)
